define(["require", "exports", 'Scripts/MindFusion.Charting'], function (require, exports, m) {
    "use strict";
	
	var Charting = m.MindFusion.Charting;
	var Controls = m.MindFusion.Charting.Controls;
	var Collections = m.MindFusion.Charting.Collections;
	var Drawing = m.MindFusion.Charting.Drawing;
	
	var currencyChart = new Controls.AreaChart(document.getElementById('currencyChart'));
	
	currencyChart.title = "The Big Corporation";
	currencyChart.theme.titleFontSize = 16;
	
	currencyChart.showLegend = false;
	currencyChart.showXCoordinates = false;
	currencyChart.xAxisLabelRotationAngle = 30;
	
	currencyChart.yAxis.minValue = 106;
	currencyChart.yAxis.interval = 0.1;
	currencyChart.yAxis.maxValue = 109;
	currencyChart.xAxis.title = "Time";
	currencyChart.yAxis.title = "Price";
	
	currencyChart.gridType = Charting.GridType.Horizontal;
	currencyChart.theme.gridColor1 = new Drawing.Color("#ffffff");
	currencyChart.theme.gridColor2 = new Drawing.Color("#fafafa");
	currencyChart.theme.gridLineColor = new Drawing.Color("#cecece");
	currencyChart.theme.gridLineStyle = Drawing.DashStyle.Dash;
	
	currencyChart.theme.axisLabelsBrush = currencyChart.theme.axisTitleBrush = currencyChart.theme.axisStroke = new Drawing.Brush("#2e2e2e"); 
	currencyChart.theme.highlightStroke = new Drawing.Brush("#cecece");
	
	
	
	var valueList = new Collections.List();
	var timeList = new Collections.List();
	updateCurrency();
	
	function updateCurrency()
	{
			$.getJSON("https://www.alphavantage.co/query?function=CURRENCY_EXCHANGE_RATE&from_currency=USD&to_currency=JPY&apikey=demo", function(json) {
		
		    var rate = json["Realtime Currency Exchange Rate"];
			  
			valueList.add(parseFloat(rate["5. Exchange Rate"]));
			timeList.add(new Date(rate["6. Last Refreshed"]));
			
			if (valueList.count() > 10)
			{
				valueList.removeAt(0);
				timeList.removeAt(0);
			}
			  
			  var series = new Charting.DateTimeSeries(timeList, valueList, timeList.item(0), timeList.item(timeList.count() - 1));
			  series.dateTimeFormat = Charting.DateTimeFormat.ShortTime;
			  
			  var data = new Collections.ObservableCollection();
			  data.add(series);
			  currencyChart.series = data;
			  currencyChart.draw();  
		});
	}
	
	setInterval(updateCurrency, 10000);
	
});